const prodURL = 'https://ui.hdhomerun.com/ui/asset-manifest.json?app=tizen';
const testURL = 'http://192.168.1.14:9999/asset-manifest.json';
const testBaseURL = 'http://192.168.1.14:9999/';

const debugging = false;
const fetchURL = debugging ? testURL : prodURL;


var init = async function () {
	try {		
	    let response = await fetch(fetchURL);
	    let data = await response.json();
	    const baseURL = debugging ? testBaseURL : extractBaseURL(response.url)
	    
	    loadFile('css', baseURL + data["main.css"]);
	    loadFile('js', baseURL + data["main.js"]);
	} catch(e) {
		console.log(e);
		handleError();
	}
};

function extractBaseURL(URL) {
	let array = URL.split('/');
	let protocol = array[0];
	let host = array[2];
	return protocol + '//' + host+ '/ui/';
}

function handleError() {	
	loadFile('css', './css/err.css');	
	document.addEventListener('keydown', function(e) {
		if (e.keyCode === 10009) {
			tizen.application.getCurrentApplication().exit();			
		}
	});	
	
	
	let errText1 = document.createElement('p');
	let errText2 = document.createElement('p');
	errText1.innerHTML = 'Unable to communicate with server';
	errText2.innerHTML = 'Please check that this device has internet access';
	
	const err = document.getElementById('err');	
	err.appendChild(errText1);
	err.appendChild(errText2);
}


function loadFile(fileType, URL){
	const head = document.getElementsByTagName('head')[0];

	let fileRef;
	
	if (fileType=="js"){
		fileRef = document.createElement('script');
	    fileRef.setAttribute("type","text/javascript");
	    fileRef.setAttribute("src", URL);
	}
	else if (fileType=="css"){
	    fileRef = document.createElement("link");
	    fileRef.setAttribute("rel", "stylesheet");
		fileRef.setAttribute("type", "text/css");
		fileRef.setAttribute("href", URL);
	}
	
	head.appendChild(fileRef);
};

window.onload = init;